# **Publish to TestPyPI (safe rehearsal)**
username ="__token__"
password ="pypi-AgENdGVzdC5weXBpLm9yZwIkOWU4NTlmMmEtMzI0Mi00MmUxLWFhMWMtMmU1ZDFlYzQ0MWE5AAIqWzMsImI2MDI4MmViLTgyZjEtNGVhYS05YzRhLTNjNGNiY2Y0N2U2ZCJdAAAGIJX_9QkbgMNH6QbHBPyui0y3a0se0TuGwr3v9LL7GZTG"

---

# **Publish to real PyPI**
username ="__token__"
password ="pypi-AgEIcHlwaS5vcmcCJDIwN2RkZDAwLTMxMjEtNDRhYy05ZmU5LTU0NmI5NDBmYjQ3ZgACKlszLCI4YWQ4YWUzZi0zY2NiLTRiZjQtOTA0Yy02ZThlYTVmYjczOTQiXQAABiAVlVBvdlf2El3v6HcnZeugYqElYDVqR06MNLTpuD8aEQ"
